@@ -28,6 +28,7 @@ import math
 import os
 from contextlib import contextmanager
 from datetime import date, datetime
+from functools import reduce
 
 import dtoolcore
 
@@ -88,9 +89,7 @@ def human_readable_file_size(num, suffix='B'):
     val = num / math.pow(1024, magnitude)
     if magnitude > 7:
         return '{:.1f}{}{}'.format(val, 'Yi', suffix)
-    return '{:3.1f}{}{}'.format(val,
-                                ['', 'Ki', 'Mi', 'Gi', 'Ti', 'Pi', 'Ei', 'Zi'][
-                                    magnitude], suffix)
+    return '{:3.1f}{}{}'.format(val, ['', 'Ki', 'Mi', 'Gi', 'Ti', 'Pi', 'Ei', 'Zi'][magnitude], suffix)
 
 
 def fill_readme_tree_store(store, data, parent=None):
@@ -136,9 +135,24 @@ def fill_readme_tree_store(store, data, parent=None):
 
 
 def fill_manifest_tree_store(store, data, parent=None):
-    for uuid, values in data.items():
-        store.append(parent,
-                     [values['relpath'],
+    nodes = {}
+
+    def find_or_create_parent_node(path, top_parent):
+        if not path:
+            return top_parent
+        try:
+            return nodes[path]
+        except KeyError:
+            head, tail = os.path.split(path)
+            parent = find_or_create_parent_node(head, top_parent)
+            new_node = store.append(parent, [tail, '', '', ''])
+            nodes[path] = new_node
+            return new_node
+
+    for uuid, values in sorted(data.items(), key=lambda kv: kv[1]['relpath']):
+        head, tail = os.path.split(values['relpath'])
+        store.append(find_or_create_parent_node(head, parent),
+                     [tail,
                       human_readable_file_size(values['size_in_bytes']),
                       f'{date_to_string(values["utc_timestamp"])}',
                       uuid])
@@ -207,7 +221,7 @@ class SignalHandler:
         results_widget = self.builder.get_object('search-results')
         statusbar_widget = self.builder.get_object('main-statusbar')
         statusbar_widget.push(0, f'{len(self.datasets)} datasets - '
-                                 f'Connect to lookup server version '
+                                 f'Connected to lookup server version '
                                  f"{self.server_config['version']}")
 
         if len(self.datasets) == 0:
@@ -270,7 +284,10 @@ class SignalHandler:
         store = manifest_view.get_model()
         store.clear()
         self._manifest = await self.lookup.manifest(uri)
-        fill_manifest_tree_store(store, self._manifest['items'])
+        try:
+            fill_manifest_tree_store(store, self._manifest['items'])
+        except Exception as e:
+            print(e)
         manifest_view.columns_autosize()
         manifest_view.show_all()
 
@@ -288,6 +305,12 @@ class SignalHandler:
             self.lookup, self._selected_dataset['uuid'],
             dependency_keys=self.settings.dependency_keys)
 
+        # Show message if uuids are missing
+        missing_uuids = self._dependency_graph.missing_uuids
+        if missing_uuids:
+            self.show_error('The following UUIDs were found during dependency graph calculation but are not present '
+                            'in the database: {}'.format(reduce(lambda a, b: a+', '+b, missing_uuids)))
+
         # Create graph widget
         graph_widget = GraphWidget(self.builder, self._dependency_graph.graph)
         dependency_view = self.builder.get_object('dependency-view')
@@ -312,12 +335,15 @@ class SignalHandler:
             self.server_config = await self.lookup.config()
             self.datasets = await self.lookup.all()
         except Exception as e:
-            self.error_label.set_text(str(e))
-            self.error_bar.show()
-            self.error_bar.set_revealed(True)
+            self.show_error(str(e))
             self.datasets = []
         self._refresh_results()
 
+    def show_error(self, msg):
+        self.error_label.set_text(msg)
+        self.error_bar.show()
+        self.error_bar.set_revealed(True)
+
     def on_window_destroy(self, *args):
         self.event_loop.stop()
 
